@@ -1,5 +1,6 @@
 """ Main Application """
 import logging
+import os
 import tempfile
 from datetime import datetime
 
@@ -18,6 +19,10 @@ from nowcasting_forecast.models.nwp_solar_simple import nwp_irradiance_simple_ru
 from nowcasting_forecast.utils import floor_30_minutes_dt
 
 logger = logging.getLogger(__name__)
+logging.basicConfig(
+    level=getattr(logging, os.getenv("LOGLEVEL", "INFO")),
+    format="[%(asctime)s] {%(pathname)s:%(lineno)d} %(levelname)s - %(message)s",
+)
 
 
 @click.command()
